@@ -1,3 +1,6 @@
+#include <stdlib.h>
+
+#include <clutter/clutter.h>
 #include <clutter-gst/clutter-gst.h>
 
 #define SEEK_H 20
@@ -29,7 +32,7 @@ control_tl_cb (ClutterTimeline *timeline,
   clutter_actor_hide (app->paused ? app->control_pause : app->control_play);
   clutter_actor_show (app->paused ? app->control_play : app->control_pause);
 
-  opacity = ( frame_num * 0xde ) / clutter_timeline_get_n_frames(timeline);
+  opacity = ( frame_num * 0xde ) / clutter_timeline_get_n_frames (timeline);
 
   if (!app->controls_showing)
     opacity = 0xde - opacity;
@@ -65,9 +68,8 @@ show_controls (VideoApp *app, gboolean vis)
       app->controls_showing = TRUE;
       clutter_timeline_start (app->controls_tl);
 
-      app->controls_timeout = g_timeout_add (5 * 1000,  
-					     (GSourceFunc)controls_timeout_cb,
-					     app);
+      app->controls_timeout =
+        g_timeout_add_seconds (5, (GSourceFunc) controls_timeout_cb, app);
       return;
     }
 
@@ -77,10 +79,8 @@ show_controls (VideoApp *app, gboolean vis)
 	{
 	  g_source_remove (app->controls_timeout);
 
-	  app->controls_timeout 
-	    = g_timeout_add (5 * 1000,  
-			     (GSourceFunc)controls_timeout_cb,
-			     app);
+	  app->controls_timeout =
+	    g_timeout_add_seconds (5, (GSourceFunc) controls_timeout_cb, app);
 	}
       return;
     }
@@ -114,7 +114,7 @@ toggle_pause_state (VideoApp *app)
     }
 }
 
-void 
+static gboolean
 input_cb (ClutterStage *stage, 
 	  ClutterEvent *event,
 	  gpointer      user_data)
@@ -132,10 +132,7 @@ input_cb (ClutterStage *stage,
 	  ClutterActor       *actor;
 	  ClutterButtonEvent *bev = (ClutterButtonEvent *) event;
 
-	  actor 
-	    = clutter_stage_get_actor_at_pos 
-	                         (CLUTTER_STAGE(clutter_stage_get_default()),
-				  bev->x, bev->y);
+	  actor = clutter_stage_get_actor_at_pos (stage, bev->x, bev->y);
 
 	  printf("got actor %p at pos %ix%i\n", actor, bev->x, bev->y);
 
@@ -151,7 +148,8 @@ input_cb (ClutterStage *stage,
 	    {
 	      gint x, y, dist, pos;
 
-	      clutter_actor_get_abs_position (app->control_seekbar, &x, &y);
+	      clutter_actor_get_transformed_position (app->control_seekbar,
+                                                      &x, &y);
 
 	      dist = bev->x - x;
 
@@ -187,6 +185,8 @@ input_cb (ClutterStage *stage,
     default:
       break;
     }
+
+  return FALSE;
 }
 
 void
@@ -265,7 +265,7 @@ main (int argc, char *argv[])
   ClutterColor         stage_color = { 0x00, 0x00, 0x00, 0x00 };
   ClutterColor         control_color1 = { 73, 74, 77, 0xee };
   ClutterColor         control_color2 = { 0xcc, 0xcc, 0xcc, 0xff };
-  GdkPixbuf           *pixb;
+  ClutterGstVideoSink *sink;
   gint                 x,y;
 
   if (argc < 2)
@@ -281,12 +281,19 @@ main (int argc, char *argv[])
   app = g_new0(VideoApp, 1);
 
   app->vtexture = clutter_gst_video_texture_new ();
-
+  
   if (app->vtexture == NULL)
     {
       g_error("failed to create vtexture");
     }
 
+  /* Use shaders if they're available */
+  g_object_get (G_OBJECT (clutter_gst_video_texture_get_playbin (
+                          CLUTTER_GST_VIDEO_TEXTURE (app->vtexture))),
+                "video-sink", &sink,
+                NULL);
+  g_object_set (G_OBJECT (sink), "use-shaders", TRUE, NULL);
+
   /* Dont let the underlying pixbuf dictate size */
   g_object_set (G_OBJECT(app->vtexture), "sync-size", FALSE, NULL);
 
@@ -301,26 +308,14 @@ main (int argc, char *argv[])
   /* Create the control UI */
   app->control = clutter_group_new ();
 
-  pixb = gdk_pixbuf_new_from_file ("vid-panel.png", NULL);
+  app->control_bg =
+    clutter_texture_new_from_file ("vid-panel.png", NULL);
+  app->control_play =
+    clutter_texture_new_from_file ("media-actions-start.png", NULL);
+  app->control_pause =
+    clutter_texture_new_from_file ("media-actions-pause.png", NULL);
 
-  if (pixb == NULL)
-    g_error("Unable to load vid-panel.png");
-
-  app->control_bg = clutter_texture_new_from_pixbuf (pixb);
-  
-  pixb = gdk_pixbuf_new_from_file("media-actions-start.png", NULL);
-
-  if (pixb == NULL)
-    g_error("Unable to load media-actions-start.png");
-
-  app->control_play = clutter_texture_new_from_pixbuf (pixb);
-
-  pixb = gdk_pixbuf_new_from_file("media-actions-pause.png", NULL);
-
-  if (pixb == NULL)
-    g_error("Unable to load media-actions-pause.png");
-
-  app->control_pause = clutter_texture_new_from_pixbuf (pixb);
+  g_assert (app->control_bg && app->control_play && app->control_pause);
 
   app->control_seek1   = clutter_rectangle_new_with_color (&control_color1);
   app->control_seek2   = clutter_rectangle_new_with_color (&control_color2);
@@ -356,6 +351,8 @@ main (int argc, char *argv[])
 
   clutter_actor_set_position (app->control_label, 200, 40);
 
+  clutter_actor_hide (app->control);
+
   /* Add control UI to stage */
   clutter_group_add_many (CLUTTER_GROUP (stage), 
 			  app->vtexture, app->control, NULL);
@@ -393,10 +390,9 @@ main (int argc, char *argv[])
 		    G_CALLBACK (tick),
 		    app);
 
-  clutter_media_set_playing (CLUTTER_MEDIA(app->vtexture), TRUE);
+  clutter_media_set_playing (CLUTTER_MEDIA (app->vtexture), TRUE);
 
-  clutter_actor_show_all (stage);
-  // clutter_group_hide_all (CLUTTER_GROUP (app->control));
+  clutter_actor_show (stage);
 
   clutter_main();
 
